@@ -7,7 +7,7 @@ use std::{
     path::{Path, PathBuf},
 };
 
-use crate::info;
+use crate::{info, Vcs};
 
 pub const CONFIG_FILE_NAME: &str = "cargo-generate.toml";
 
@@ -29,9 +29,13 @@ pub struct FavoriteConfig {
     pub description: Option<String>,
     pub git: Option<String>,
     pub branch: Option<String>,
+    pub tag: Option<String>,
     pub subfolder: Option<String>,
     pub path: Option<PathBuf>,
     pub values: Option<HashMap<String, toml::Value>>,
+    pub vcs: Option<Vcs>,
+    pub init: Option<bool>,
+    pub overwrite: Option<bool>,
 }
 
 #[derive(Deserialize, Default)]
@@ -58,6 +62,7 @@ impl TryFrom<&Path> for AppConfig {
     }
 }
 
+/// # Panics
 pub fn app_config_path(path: &Option<PathBuf>) -> Result<PathBuf> {
     path.as_ref()
         .map(|p| p.canonicalize().unwrap())
