@@ -5,6 +5,7 @@ use std::{
 
 use anyhow::{anyhow, Result};
 use clap::{Args, Parser};
+use serde::Deserialize;
 
 use crate::git;
 
@@ -42,7 +43,8 @@ pub struct GenerateArgs {
             "define",
             "init",
             "template-values-file",
-            "ssh-identity"
+            "ssh-identity",
+            "test",
         ])
     )]
     pub list_favorites: bool,
@@ -77,10 +79,10 @@ pub struct GenerateArgs {
     pub config: Option<PathBuf>,
 
     /// Specify the VCS used to initialize the generated template.
-    #[clap(long, default_value = "git", value_parser)]
-    pub vcs: Vcs,
+    #[clap(long, value_parser)]
+    pub vcs: Option<Vcs>,
 
-    /// Populates a template variable `crate_type` with value `"lib"`
+    /// Populates template variable `crate_type` with value `"lib"`
     #[clap(long, conflicts_with = "bin", action)]
     pub lib: bool,
 
@@ -97,11 +99,11 @@ pub struct GenerateArgs {
     pub define: Vec<String>,
 
     /// Generate the template directly into the current dir. No subfolder will be created and no vcs is initialized.
-    #[clap(long, conflicts_with = "destination", action)]
+    #[clap(long, action)]
     pub init: bool,
 
     /// Generate the template directly at the given path.
-    #[clap(long, conflicts_with = "init", value_parser)]
+    #[clap(long, value_parser)]
     pub destination: Option<PathBuf>,
 
     /// Will enforce a fresh git init on the generated project
@@ -113,6 +115,14 @@ pub struct GenerateArgs {
     /// Use at your own risk and be sure to review the template code beforehand.
     #[clap(short, long, action)]
     pub allow_commands: bool,
+
+    /// Allow the template to overwrite existing files in the destination.
+    #[clap(short, long, action)]
+    pub overwrite: bool,
+
+    /// All args after "--" on the command line.
+    #[clap(skip)]
+    pub other_args: Option<Vec<String>>,
 }
 
 #[derive(Debug, Clone, Args)]
@@ -126,6 +136,12 @@ pub struct TemplatePath {
     #[clap()]
     pub subfolder: Option<String>,
 
+    /// Expand $CWD as a template, then run `cargo test` on the expansion (set $CARGO_GENERATE_TEST_CMD to override test command).
+    ///
+    /// Any arguments given after the `--test` argument, will be used as arguments for the test command.
+    #[clap(long, action, group("SpecificPath"))]
+    pub test: bool,
+
     /// Git repository to clone template from. Can be a URL (like
     /// `https://github.com/rust-cli/cli-template`), a path (relative or absolute), or an
     /// `owner/repo` abbreviated GitHub URL (like `rust-cli/cli-template`).
@@ -136,9 +152,13 @@ pub struct TemplatePath {
     pub git: Option<String>,
 
     /// Branch to use when installing from git
-    #[clap(short, long)]
+    #[clap(short, long, conflicts_with = "tag")]
     pub branch: Option<String>,
 
+    /// Tag to use when installing from git
+    #[clap(short, long, conflicts_with = "branch")]
+    pub tag: Option<String>,
+
     /// Local path to copy the template from. Can not be specified together with --git.
     #[clap(short, long, group("SpecificPath"))]
     pub path: Option<String>,
@@ -170,6 +190,10 @@ impl TemplatePath {
         self.branch.as_ref()
     }
 
+    pub const fn tag(&self) -> Option<&(impl AsRef<str> + '_)> {
+        self.tag.as_ref()
+    }
+
     pub const fn path(&self) -> Option<&(impl AsRef<str> + '_)> {
         self.path.as_ref()
     }
@@ -191,7 +215,7 @@ impl TemplatePath {
     }
 }
 
-#[derive(Debug, Parser, Clone, Copy)]
+#[derive(Debug, Parser, Clone, Copy, PartialEq, Eq, Deserialize)]
 pub enum Vcs {
     None,
     Git,
