@@ -1,4 +1,4 @@
-//! Input from user but after prase
+//! Input from user but after parse
 
 use std::{
     collections::HashMap,
@@ -8,9 +8,10 @@ use std::{
 use console::style;
 use regex::Regex;
 
-use crate::{app_config::AppConfig, warn, GenerateArgs};
+use crate::{app_config::AppConfig, warn, GenerateArgs, Vcs};
 
 // Contains parsed information from user.
+#[derive(Debug)]
 pub struct UserParsedInput {
     // from where clone or copy template?
     template_location: TemplateLocation,
@@ -21,6 +22,9 @@ pub struct UserParsedInput {
     // 2. configuration file
     // 3. cli arguments --define
     template_values: HashMap<String, toml::Value>,
+    vcs: Vcs,
+    pub init: bool,
+    overwrite: bool,
     //TODO:
     // 1. This structure should be used instead of args
     // 2. This struct can contains internaly args and app_config to not confuse
@@ -28,15 +32,21 @@ pub struct UserParsedInput {
 }
 
 impl UserParsedInput {
-    fn new<T: AsRef<str>>(
+    fn new(
         template_location: impl Into<TemplateLocation>,
-        subfolder: Option<T>,
+        subfolder: Option<impl AsRef<str>>,
         default_values: HashMap<String, toml::Value>,
+        vcs: Vcs,
+        init: bool,
+        overwrite: bool,
     ) -> Self {
         Self {
             template_location: template_location.into(),
             subfolder: subfolder.map(|s| s.as_ref().to_owned()),
             template_values: default_values,
+            vcs,
+            init,
+            overwrite,
         }
     }
 
@@ -45,7 +55,9 @@ impl UserParsedInput {
     /// # Panics
     /// This function assume that Args and AppConfig are verfied eariler and are logicly correct
     /// For example if both `--git` and `--path` are set this function will panic
-    pub fn try_from_args_and_config(app_config: &AppConfig, args: &GenerateArgs) -> Self {
+    pub fn try_from_args_and_config(app_config: AppConfig, args: &GenerateArgs) -> Self {
+        const DEFAULT_VCS: Vcs = Vcs::Git;
+
         let mut default_values = app_config.values.clone().unwrap_or_default();
         let ssh_identity = app_config
             .defaults
@@ -58,10 +70,18 @@ impl UserParsedInput {
             let git_user_in = GitUserInput::new(
                 git_url,
                 args.template_path.branch(),
+                args.template_path.tag(),
                 ssh_identity,
                 args.force_git_init,
             );
-            return Self::new(git_user_in, args.template_path.subfolder(), default_values);
+            return Self::new(
+                git_user_in,
+                args.template_path.subfolder(),
+                default_values,
+                args.vcs.unwrap_or(DEFAULT_VCS),
+                args.init,
+                args.overwrite,
+            );
         }
 
         // --path
@@ -70,6 +90,9 @@ impl UserParsedInput {
                 path.as_ref(),
                 args.template_path.subfolder(),
                 default_values,
+                args.vcs.unwrap_or(DEFAULT_VCS),
+                args.init,
+                args.overwrite,
             );
         }
 
@@ -87,9 +110,15 @@ impl UserParsedInput {
                         .branch()
                         .map(|s| s.as_ref().to_owned())
                         .or_else(|| fav_cfg.branch.clone());
+                    let tag = args
+                        .template_path
+                        .tag()
+                        .map(|s| s.as_ref().to_owned())
+                        .or_else(|| fav_cfg.tag.clone());
                     let git_user_input = GitUserInput::new(
                         git_url,
                         branch.as_ref(),
+                        tag.as_ref(),
                         ssh_identity,
                         args.force_git_init,
                     );
@@ -109,6 +138,12 @@ impl UserParsedInput {
                     .map(|s| s.as_ref().to_owned())
                     .or_else(|| fav_cfg.subfolder.clone()),
                 default_values,
+                args.vcs.or(fav_cfg.vcs).unwrap_or(DEFAULT_VCS),
+                args.init.then(|| true).or(fav_cfg.init).unwrap_or_default(),
+                args.overwrite
+                    .then(|| true)
+                    .or(fav_cfg.overwrite)
+                    .unwrap_or_default(),
             );
         }
 
@@ -138,6 +173,7 @@ impl UserParsedInput {
             let git_user_in = GitUserInput::new(
                 &fav_name,
                 args.template_path.branch(),
+                args.template_path.tag(),
                 ssh_identity,
                 args.force_git_init,
             );
@@ -165,6 +201,9 @@ impl UserParsedInput {
                 .subfolder()
                 .map(|s| s.as_ref().to_owned()),
             default_values,
+            args.vcs.unwrap_or(DEFAULT_VCS),
+            args.init,
+            args.overwrite,
         )
     }
 
@@ -183,6 +222,18 @@ impl UserParsedInput {
     pub fn template_values_mut(&mut self) -> &mut HashMap<String, toml::Value> {
         &mut self.template_values
     }
+
+    pub const fn vcs(&self) -> Vcs {
+        self.vcs
+    }
+
+    pub const fn init(&self) -> bool {
+        self.init
+    }
+
+    pub const fn overwrite(&self) -> bool {
+        self.overwrite
+    }
 }
 
 // favorite can be in form with abbrevation what means that input is git repositoru
@@ -214,40 +265,38 @@ pub fn local_path(fav: &str) -> Option<PathBuf> {
 }
 
 // Template should be cloned with git
+#[derive(Debug)]
 pub struct GitUserInput {
     url: String,
     branch: Option<String>,
+    tag: Option<String>,
     identity: Option<PathBuf>,
     _force_init: bool,
 }
 
 impl GitUserInput {
-    fn new<T1, T2>(
-        url: &T1,
-        branch: Option<&T2>,
+    fn new(
+        url: &impl AsRef<str>,
+        branch: Option<&impl AsRef<str>>,
+        tag: Option<&impl AsRef<str>>,
         identity: Option<PathBuf>,
         force_init: bool,
-    ) -> Self
-    where
-        T1: AsRef<str>,
-        T2: AsRef<str>,
-    {
+    ) -> Self {
         Self {
             url: url.as_ref().to_owned(),
             branch: branch.map(|s| s.as_ref().to_owned()),
+            tag: tag.map(|s| s.as_ref().to_owned()),
             identity,
             _force_init: force_init,
         }
     }
 
     // when git was used as abbreviation but other flags still could be passed
-    fn with_git_url_and_args<T1>(url: &T1, args: &GenerateArgs) -> Self
-    where
-        T1: AsRef<str>,
-    {
+    fn with_git_url_and_args(url: &impl AsRef<str>, args: &GenerateArgs) -> Self {
         Self::new(
             url,
             args.template_path.branch(),
+            args.template_path.tag(),
             args.ssh_identity.clone(),
             args.force_git_init,
         )
@@ -261,12 +310,17 @@ impl GitUserInput {
         self.branch.as_deref()
     }
 
+    pub fn tag(&self) -> Option<&str> {
+        self.tag.as_deref()
+    }
+
     pub fn identity(&self) -> Option<&Path> {
         self.identity.as_deref()
     }
 }
 
 // Distinguish between plain copy and clone
+#[derive(Debug)]
 pub enum TemplateLocation {
     Git(GitUserInput),
     Path(PathBuf),
