@@ -1,4 +1,5 @@
 use git2::Repository;
+use indoc::indoc;
 use predicates::prelude::*;
 
 use crate::helpers::project::binary;
@@ -461,6 +462,44 @@ version = "0.1.0"
     Ok(())
 }
 
+#[test]
+fn it_can_overwrite_files() -> anyhow::Result<()> {
+    let template = tmp_dir()
+        .file(
+            "Cargo.toml",
+            r#"[package]
+name = "{{project-name}}"
+description = "A wonderful project"
+version = "0.1.0"
+"#,
+        )
+        .init_git()
+        .build();
+    let dir = tmp_dir().build();
+    let _ = binary()
+        .arg("generate")
+        .arg("--git")
+        .arg(template.path())
+        .arg("--name")
+        .arg("my-proj")
+        .arg("--init")
+        .current_dir(&dir.path())
+        .status();
+    binary()
+        .arg("generate")
+        .arg("--git")
+        .arg(template.path())
+        .arg("--name")
+        .arg("overwritten-proj")
+        .arg("--init")
+        .arg("--overwrite")
+        .current_dir(&dir.path())
+        .assert()
+        .success();
+    assert!(dir.read("Cargo.toml").contains("overwritten-proj"));
+    Ok(())
+}
+
 #[test]
 fn it_allows_user_defined_projectname_when_passing_force_flag() {
     let template = tmp_dir()
@@ -1101,10 +1140,10 @@ fn it_doesnt_warn_with_neither_config_nor_ignore() {
         .file(
             "Cargo.toml",
             r#"[package]
-    name = "{{project-name}}"
-    description = "A wonderful project"
-    version = "0.1.0"
-    "#,
+name = "{{project-name}}"
+description = "A wonderful project"
+version = "0.1.0"
+"#,
         )
         .init_git()
         .build();
@@ -1131,11 +1170,16 @@ fn it_applies_filters() {
     let template = tmp_dir()
         .file(
             "filters.txt",
-            r#"kebab-case = {{crate_name | kebab_case}}
-    PascalCase = {{crate_name | pascal_case}}
-    snake_case = {{crate_name | snake_case}}
-    without_suffix = {{crate_name | split: "_" | first}}
-    "#,
+            r#"kebab_case = {{"some text" | kebab_case}}
+lower_camel_case = {{"some text" | lower_camel_case}}
+pascal_case = {{"some text" | pascal_case}}
+shouty_kebab_case = {{"some text" | shouty_kebab_case}}
+shouty_snake_case = {{"some text" | shouty_snake_case}}
+snake_case = {{"some text" | snake_case}}
+title_case = {{"some text" | title_case}}
+upper_camel_case = {{"some text" | upper_camel_case}}
+without_suffix = {{crate_name | split: "_" | first}}
+"#,
         )
         .init_git()
         .build();
@@ -1156,10 +1200,14 @@ fn it_applies_filters() {
         .stdout(predicates::str::contains("Done!").from_utf8());
 
     let cargo_toml = dir.read("foobar-project/filters.txt");
-    assert!(cargo_toml.contains("kebab-case = foobar-project"));
-    assert!(cargo_toml.contains("PascalCase = FoobarProject"));
-    assert!(cargo_toml.contains("snake_case = foobar_project"));
-    assert!(cargo_toml.contains("without_suffix = foobar"));
+    assert!(cargo_toml.contains("kebab_case = some-text"));
+    assert!(cargo_toml.contains("lower_camel_case = someText"));
+    assert!(cargo_toml.contains("pascal_case = SomeText"));
+    assert!(cargo_toml.contains("shouty_kebab_case = SOME-TEXT"));
+    assert!(cargo_toml.contains("shouty_snake_case = SOME_TEXT"));
+    assert!(cargo_toml.contains("snake_case = some_text"));
+    assert!(cargo_toml.contains("title_case = Some Text"));
+    assert!(cargo_toml.contains("upper_camel_case = SomeText"));
     assert!(!cargo_toml.contains("without_suffix = foobar_project"));
 }
 
@@ -1267,6 +1315,46 @@ version = "0.1.0"
     assert!(Repository::open(dir.path().join("foobar-project")).is_err());
 }
 
+#[test]
+fn vsc_none_can_be_specified_in_the_template() {
+    // Build and commit on branch named 'main'
+    let template = tmp_dir()
+        .file(
+            "Cargo.toml",
+            r#"[package]
+name = "{{project-name}}"
+description = "A wonderful project"
+version = "0.1.0"
+"#,
+        )
+        .file(
+            "cargo-generate.toml",
+            r#"[template]
+vcs = "None"
+"#,
+        )
+        .init_git()
+        .build();
+
+    let dir = tmp_dir().build();
+
+    binary()
+        .arg("generate")
+        .arg("--git")
+        .arg(template.path())
+        .arg("--name")
+        .arg("foobar-project")
+        .current_dir(&dir.path())
+        .assert()
+        .success()
+        .stdout(predicates::str::contains("Done!").from_utf8());
+
+    assert!(dir
+        .read("foobar-project/Cargo.toml")
+        .contains("foobar-project"));
+    assert!(Repository::open(dir.path().join("foobar-project")).is_err());
+}
+
 #[test]
 fn it_provides_crate_type_lib() {
     // Build and commit on branch named 'main'
@@ -1425,3 +1513,45 @@ fn error_message_for_invalid_repo_or_user() {
                 .from_utf8(),
         );
 }
+
+#[test]
+fn a_template_can_specify_to_be_generated_into_cwd() -> anyhow::Result<()> {
+    let template = tmp_dir()
+        .file(
+            "Cargo.toml",
+            indoc! {r#"
+                [package]
+                name = "{{project-name}}"
+                description = "A wonderful project"
+                version = "0.1.0"
+                "#},
+        )
+        .file(
+            "cargo-generate.toml",
+            indoc! {r#"
+                [template]
+                init = true
+                "#},
+        )
+        .init_git()
+        .build();
+
+    let dir = tmp_dir().build();
+
+    binary()
+        .arg("gen")
+        .arg("--git")
+        .arg(template.path())
+        .arg("-n")
+        .arg("foobar-project")
+        .arg("--branch")
+        .arg("main")
+        .current_dir(&dir.path())
+        .assert()
+        .success()
+        .stdout(predicates::str::contains("Done!").from_utf8());
+
+    assert!(dir.exists("Cargo.toml"));
+    assert!(!dir.path().join(".git").exists());
+    Ok(())
+}
