@@ -11,6 +11,7 @@ pub struct ProjectBuilder {
     root: TempDir,
     git: bool,
     branch: Option<String>,
+    tag: Option<String>,
 }
 
 pub fn tmp_dir() -> ProjectBuilder {
@@ -20,6 +21,7 @@ pub fn tmp_dir() -> ProjectBuilder {
         root: tempdir().unwrap(),
         git: false,
         branch: None,
+        tag: None,
     }
 }
 
@@ -55,7 +57,16 @@ version = "0.1.0"
         self
     }
 
-    pub fn add_submodule<I: Into<String>>(mut self, destination: I, path: I) -> Self {
+    pub fn tag(mut self, tag: &str) -> Self {
+        self.tag = Some(tag.to_owned());
+        self
+    }
+
+    pub fn add_submodule(
+        mut self,
+        destination: impl Into<String>,
+        path: impl Into<String>,
+    ) -> Self {
         self.submodules.push((destination.into(), path.into()));
         self
     }
@@ -163,6 +174,40 @@ version = "0.1.0"
                 .assert()
                 .success();
 
+            if let Some(ref tag) = self.tag {
+                Command::new("git")
+                    .arg("tag")
+                    .arg("-a")
+                    .arg(tag)
+                    .arg("-m")
+                    .arg(format!("our test tag {tag}"))
+                    .current_dir(&path)
+                    .assert()
+                    .success();
+
+                for &(ref file, _) in self.files.iter() {
+                    let path = path.join(file);
+                    fs::remove_file(&path).unwrap_or_else(|_| {
+                        panic!("couldn't remove file {path:?}, after commiting tag {tag}")
+                    });
+                }
+
+                Command::new("git")
+                    .arg("add")
+                    .arg("--all")
+                    .current_dir(&path)
+                    .assert()
+                    .success();
+
+                Command::new("git")
+                    .arg("commit")
+                    .arg("--message")
+                    .arg("dummy commit after tag")
+                    .current_dir(&path)
+                    .assert()
+                    .success();
+            }
+
             if self.branch.is_some() {
                 Command::new("git")
                     .arg("checkout")
